@@ -1,7 +1,9 @@
 package App::RecordStream::Aggregator::DistinctCount;
 
+our $VERSION = "4.0.0";
+
 use strict;
-use lib;
+use warnings;
 
 use App::RecordStream::Aggregator;
 use App::RecordStream::DomainLanguage::Registry;
@@ -11,74 +13,72 @@ use base qw(App::RecordStream::Aggregator::Aggregation);
 
 sub new
 {
-   my $class = shift;
-   my $field = shift;
+  my $class = shift;
+  my $field = shift;
 
-   return new_from_valuation($class, App::RecordStream::DomainLanguage::Valuation::KeySpec->new($field));
+  return new_from_valuation($class, App::RecordStream::DomainLanguage::Valuation::KeySpec->new($field));
 }
 
 sub new_from_valuation
 {
-   my $class = shift;
-   my ($valuation) = @_;
+  my $class = shift;
+  my ($valuation) = @_;
 
-   my $this =
-   {
-      'valuation' => $valuation,
-   };
-   bless $this, $class;
+  my $this =
+  {
+    'valuation' => $valuation,
+  };
+  bless $this, $class;
 
-   return $this;
+  return $this;
 }
 
 sub squish
 {
-   my ($this, $cookie) = @_;
+  my ($this, $cookie) = @_;
 
-   return scalar(keys(%$cookie));
+  return scalar(keys(%$cookie));
 }
 
 sub short_usage
 {
-   return "count unique values from provided field";
+  return "count unique values from provided field";
 }
 
 sub long_usage
 {
-   print <<USAGE;
+  return <<EOF;
 Usage: dct,<field>
    Finds the number of unique values for a field and returns it.  Will load all
    values into memory.
-USAGE
-
-   exit 1
+EOF
 }
 
 sub argct
 {
-   return 1;
+  return 1;
 }
 
 sub initial
 {
-   return {};
+  return {};
 }
 
 sub combine
 {
-   my ($this, $cookie, $record) = @_;
+  my ($this, $cookie, $record) = @_;
 
-   my $value = $this->{'valuation'}->evaluate_record($record);
+  my $value = $this->{'valuation'}->evaluate_record($record);
 
-   $cookie->{$value} = 1;
+  $cookie->{$value} = 1;
 
-   return $cookie;
+  return $cookie;
 }
 
-App::RecordStream::Aggregator::register_aggregator('dcount', __PACKAGE__);
-App::RecordStream::Aggregator::register_aggregator('dct', __PACKAGE__);
-App::RecordStream::Aggregator::register_aggregator('distinctcount', __PACKAGE__);
-App::RecordStream::Aggregator::register_aggregator('distinctct', __PACKAGE__);
+App::RecordStream::Aggregator->register_implementation('dcount', __PACKAGE__);
+App::RecordStream::Aggregator->register_implementation('dct', __PACKAGE__);
+App::RecordStream::Aggregator->register_implementation('distinctcount', __PACKAGE__);
+App::RecordStream::Aggregator->register_implementation('distinctct', __PACKAGE__);
 
 App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'dcount', 'VALUATION');
 App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'dct', 'VALUATION');
