@@ -1,7 +1,9 @@
 package App::RecordStream::Aggregator::First;
 
+our $VERSION = "4.0.0";
+
 use strict;
-use lib;
+use warnings;
 
 use App::RecordStream::Aggregator::InjectInto::Field;
 use App::RecordStream::DomainLanguage::Registry;
@@ -14,26 +16,27 @@ use base qw(App::RecordStream::Aggregator::InjectInto::Field);
 
 sub combine_field
 {
-   my $this   = shift;
-   my $cookie = shift;
-   my $value  = shift;
+  my $this   = shift;
+  my $cookie = shift;
+  my $value  = shift;
 
-   return defined($cookie) ? $cookie : $value;
+  return defined($cookie) ? $cookie : $value;
 }
 
 sub short_usage
 {
-   return "first value for a field";
+  return "first value for a field";
 }
 
 sub long_usage
 {
-   print "Usage: first,<field>\n";
-   print "   First value of specified field.\n";
-   exit 1;
+  return <<EOF;
+Usage: first,<field>
+   First value of specified field.
+EOF
 }
 
-App::RecordStream::Aggregator::register_aggregator('first', __PACKAGE__);
+App::RecordStream::Aggregator->register_implementation('first', __PACKAGE__);
 
 App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'first', 'VALUATION');
 
