@@ -1,7 +1,9 @@
 package App::RecordStream::Aggregator::Mode;
 
+our $VERSION = "4.0.0";
+
 use strict;
-use lib;
+use warnings;
 
 use App::RecordStream::Aggregator::InjectInto::Field;
 use App::RecordStream::DomainLanguage::Registry;
@@ -13,55 +15,53 @@ use base qw(App::RecordStream::Aggregator::InjectInto::Field);
 #sub new_from_valuation -- passed through
 
 sub initial {
-   return {};
+  return {};
 }
 
 sub combine_field
 {
-   my $this   = shift;
-   my $cookie = shift;
-   my $value  = shift;
+  my $this   = shift;
+  my $cookie = shift;
+  my $value  = shift;
 
-   $cookie->{$value}++;
-   return $cookie;
+  $cookie->{$value}++;
+  return $cookie;
 }
 
 sub squish {
-   my $this   = shift;
-   my $cookie = shift;
+  my $this   = shift;
+  my $cookie = shift;
 
-   my @keys      = keys %$cookie;
-   my $max_key   = shift @keys;
-   my $max_value = $cookie->{$max_key};
+  my @keys      = keys %$cookie;
+  my $max_key   = shift @keys;
+  my $max_value = $cookie->{$max_key};
 
-   foreach my $key ( @keys ) {
-      my $value = $cookie->{$key};
-      if ( $max_value < $value ) {
-         $max_key   = $key;
-         $max_value = $value;
-      }
-   }
+  foreach my $key ( @keys ) {
+    my $value = $cookie->{$key};
+    if ( $max_value < $value ) {
+      $max_key   = $key;
+      $max_value = $value;
+    }
+  }
 
-   return $max_key;
+  return $max_key;
 }
 
 sub short_usage
 {
-   return "most common value for a field";
+  return "most common value for a field";
 }
 
 sub long_usage
 {
-   print <<USAGE;
+  print <<EOF;
 Usage: mode,<field>
    Finds the most common value for a field and returns it.
    Will load all values into memory.
-USAGE
-
-   exit 1
+EOF
 }
 
-App::RecordStream::Aggregator::register_aggregator('mode', __PACKAGE__);
+App::RecordStream::Aggregator->register_implementation('mode', __PACKAGE__);
 
 App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'mode', 'VALUATION');
 
